@@ -737,7 +737,7 @@ def main():
                 # Split host string and apply to env dict
                 username, hostname, port = interpret_host_string(host)
                 # Log to stdout
-                if state.output.running:
+                if state.output.running and not hasattr(task, 'return_value'):
                     print("[%s] Executing task '%s'" % (host, name))
                 # Actually run command
                 _run_task(task, args, kwargs)
